@@ -12,6 +12,10 @@ PART=${DEVPATH##*/${PART}}
 
 DEV=${DEVNAME##*/}
 
+if echo $DEV | grep "^mmcblk"; then
+    MNT=$DEV
+else
+
 if [ ! -d /sys$DEVPATH/device ]; then
     DEVPATH=$DEVPATH/..
 fi
@@ -39,6 +43,8 @@ if [ "$REMOVABLE" != true -o "$MNT" = "$PART" ]; then
   esac
 fi
 
+fi
+
 MNT="/mnt/$MNT"
 if [ -d "$MNT" ]; then
   NUM=2
@@ -54,16 +60,24 @@ MOUNT="/bin/mount"
 UMOUNT="/bin/umount"
 
 if [ "$ACTION" = "add" ] && [ -n "$DEVNAME" ]; then
-	get_mount_dir
-	if [ -x $MOUNT ]; then
-    		$MOUNT $DEVNAME "$MNT" 2> /dev/null || rmdir "$MNT"
-	fi
+    if grep "^$DEVNAME" /etc/fstab >/dev/null ; then
+	mount $DEVNAME
+	exit 0
+    fi
+    get_mount_dir
+    if [ -x $MOUNT ]; then
+    	$MOUNT $DEVNAME "$MNT" 2> /dev/null || rmdir "$MNT"
+    fi
 fi
 
 if [ "$ACTION" = "remove" ] && [ -x "$UMOUNT" ] && [ -n "$DEVNAME" ]; then
-	for mnt in `cat /proc/mounts | grep "$DEVNAME" | cut -f 2 -d " " `
-	do
-		mnt=`printf $mnt`
-		$UMOUNT "$mnt" && rmdir "$mnt"
-	done
+    if grep "^$DEVNAME" /etc/fstab >/dev/null ; then
+	umount $DEVNAME
+	exit 0
+    fi
+    for mnt in `cat /proc/mounts | grep "$DEVNAME" | cut -f 2 -d " " `
+    do
+	mnt=`printf $mnt`
+	$UMOUNT "$mnt" && rmdir "$mnt"
+    done
 fi
